




# pyPushoverReceiver

**Note** this Api is built to work with the Pushover Receiver integration for home assistant.  No usage instruction is currently provided.

To use this api you need a pushover account and desktop license. Please visit https://pushover.net/


Changelog 


0.0.2
Added Exceptions
Added all base features for a working API


0.0.1

Initial commit and base files